"""Import a DMARC aggregated report."""

from optparse import make_option

from django.core.management.base import BaseCommand

from ... import lib


class Command(BaseCommand):

    """Command definition."""

    help = "Import DMARC aggregated reports."

    option_list = BaseCommand.option_list + (
        make_option("--pipe", action="store_true", default=False,
                    help="Import a report from an email given on stdin"),
        make_option("--imap", action="store_true", default=False,
                    help="Import a report from an IMAP mailbox"),
        make_option("--host", default="localhost",
                    help="IMAP host"),
        make_option("--ssl", action="store_true", default=False,
                    help="Connect using SSL"),
        make_option("--mailbox", default="INBOX",
                    help="IMAP mailbox to import reports from"),
    )

    def handle(self, *args, **options):
        """Entry point."""
        if options.get("pipe"):
            lib.import_report_from_stdin()
        elif options.get("imap"):
            lib.import_from_imap(options)
        elif args:
            lib.import_archive(args[0])
        else:
            print "Nothing to do."



"""DMARC tools for Modoboa."""

from django.core.urlresolvers import reverse
from django.utils.translation import ugettext_lazy, ugettext as _

from modoboa.core.extensions import ModoExtension, exts_pool
from modoboa.lib import events, parameters

from . import __version__


class DmarcExtension(ModoExtension):

    """Extension registration."""

    name = "modoboa_dmarc"
    label = ugettext_lazy("DMARC tools")
    version = __version__
    description = ugettext_lazy(
        "A set of tools to ease DMARC integration"
    )
    url = "dmarc"

    def load(self):
        """Extension loading."""
        from .app_settings import ParametersForm

        parameters.register(ParametersForm, "DMARC")


exts_pool.register_extension(DmarcExtension)


@events.observe("GetDomainActions")
def extra_domain_actions(user, domain):
    """Return a menu to show the DMARC report."""
    return [{
        "name": "dmarc_report",
        "url": reverse("modoboa_dmarc:domain_report", args=[domain.pk]),
        "title": _("Show DMARC report for {}").format(domain.name),
        "img": "fa fa-pie-chart"
    }]



"""Custom template tags."""

import datetime

from dateutil import relativedelta

from django import template
from django.utils.safestring import mark_safe

register = template.Library()


@register.simple_tag
def next_period(period):
    """Return next period."""
    current = datetime.datetime.strptime("{}-1".format(period), "%Y-%W-%w")
    current += relativedelta.relativedelta(weeks=1)
    parts = current.isocalendar()
    return mark_safe("{}-{}".format(parts[0], parts[1]))


@register.simple_tag
def previous_period(period):
    """Return previous period."""
    current = datetime.datetime.strptime("{}-1".format(period), "%Y-%W-%w")
    current += relativedelta.relativedelta(weeks=-1)
    parts = current.isocalendar()
    return mark_safe("{}-{}".format(parts[0], parts[1]))



"""Custom forms."""

from django import forms
from django.utils import timezone


class ReportOptionsForm(forms.Form):

    """Report display options."""

    current_year = forms.IntegerField(widget=forms.widgets.HiddenInput)
    current_week = forms.IntegerField()
    query = forms.ChoiceField(
        choices=[("previous", "Previous"), ("next", "Next")])
    resolve_hostnames = forms.BooleanField(
        initial=False, required=False)

    def __init__(self, *args, **kwargs):
        """Constructor."""
        super(ReportOptionsForm, self).__init__(*args, **kwargs)
        if not args:
            year, week, day = timezone.now().isocalendar()
            self.fields["current_year"].initial = year
            self.fields["current_week"].initial = week



"""DMARC urls."""

from django.conf.urls import patterns, url

from . import views

urlpatterns = patterns(
    "modoboa_dmarc.views",

    url(r"^domains/(?P<pk>\d+)/$", views.DomainReportView.as_view(),
        name="domain_report"),

)



# coding: utf-8

"""Online settings."""

from django.utils.translation import ugettext_lazy as _

from modoboa.lib.form_utils import (
    SeparatorField, YesNoField,
)
from modoboa.lib.parameters import AdminParametersForm


class ParametersForm(AdminParametersForm):

    """Extension settings."""

    app = "modoboa_dmarc"

    qsettings_sep = SeparatorField(label=_("DNS settings"))

    enable_rlookups = YesNoField(
        label=_("Enable reverse lookups"),
        initial="no",
        help_text=_(
            "Enable reverse DNS lookups (reports will be longer to display)"
        )
    )
